"""
osidb-bindings session
"""


import importlib
import os
import re
from functools import partial
from types import ModuleType
from typing import Any, Callable, Dict, List

import requests
from requests_gssapi import HTTPSPNEGOAuth

from .bindings.python_client import AuthenticatedClient, models
from .bindings.python_client.api.auth import (
    auth_token_create,
    auth_token_refresh_create,
    auth_token_retrieve,
)
from .bindings.python_client.types import UNSET
from .constants import (
    ALL_SESSION_OPERATIONS,
    OSIDB_API_VERSION,
    OSIDB_BINDINGS_API_PATH,
    OSIDB_BINDINGS_USERAGENT,
)
from .exceptions import OperationUnsupported, UndefinedRequestBody
from .iterators import Paginator

osidb_status_retrieve = importlib.import_module(
    f"{OSIDB_BINDINGS_API_PATH}.osidb_api_{OSIDB_API_VERSION}_status_retrieve",
    package="osidb_bindings",
)


def double_underscores_to_single_underscores(fn):
    """
    Function decorator which changes all the keyword arguments which include
    double underscore to use single underscore instead.

    eg. affect__affectedness -> affect_affectedness

    This change is needed because in OpenAPI schema query parameters might contain
    double underscore, howerver OpenAPI Python Client package converts all these
    double underscores into single ones and thus this creates a confusion as user
    tries to use query parameter from the OpenAPI schema specification unaware of
    the underscore change.
    """

    def inner(*args, **kwargs):
        new_kwargs = {name.replace("__", "_"): value for name, value in kwargs.items()}
        return fn(*args, **new_kwargs)

    return inner


def get_sync_function(api_module: ModuleType) -> Callable:
    """
    Get 'sync' function from API module if available (response example is defined in schema)
    or get basic 'sync_detailed' function (response example is not defined in schema)
    """
    return double_underscores_to_single_underscores(
        getattr(api_module, "sync", getattr(api_module, "sync_detailed"))
    )


def new_session(
    osidb_server_uri,
    password=None,
    username=None,
    verify_ssl=True,
):
    """Create a new session for selected OSIDB URI"""

    if username and password:

        # OSIDB instances with the username/password auth for token acquirement
        auth = (username, password)
    else:

        # OSIDB instances with the kerberos auth for token acquirement
        auth = "kerberos"

    return Session(
        base_url=osidb_server_uri.strip("/"), auth=auth, verify_ssl=verify_ssl
    )


class Session:
    """Simple session wrapper which encapsulates the client"""

    def __init__(self, base_url, auth=None, verify_ssl=True):

        # Store auth for the refresh token acquirement
        self.auth = auth

        self.__client = AuthenticatedClient(
            base_url=base_url,
            headers={
                "User-Agent": OSIDB_BINDINGS_USERAGENT,
                "Bugzilla-Api-Key": os.getenv("BUGZILLA_API_KEY"),
            },
            verify_ssl=verify_ssl,
        )

        self.flaws = SessionOperationsGroup(
            self.__get_client_with_new_access_token,
            "flaws",
            allowed_operations=(
                "retrieve",
                "update",
                "list",
                "create",
                "search",
            ),
            subresources={
                "comments": {"allowed_operations": ["retrieve", "list", "create"]},
                "references": {
                    "allowed_operations": [
                        "retrieve",
                        "update",
                        "list",
                        "create",
                        "destroy",
                    ]
                },
            },
        )
        self.affects = SessionOperationsGroup(
            self.__get_client_with_new_access_token,
            "affects",
            allowed_operations=(
                "retrieve",
                "update",
                "list",
                "create",
                "destroy",
            ),
        )
        self.trackers = SessionOperationsGroup(
            self.__get_client_with_new_access_token,
            "trackers",
            allowed_operations=(
                "retrieve",
                "list",
            ),
        )

        self.refresh_token = self.__get_refresh_token()

    def status(self):
        status_fn = get_sync_function(osidb_status_retrieve)
        return status_fn(client=self.__get_client_with_new_access_token())

    def __get_refresh_token(self) -> str:
        """Get resfresh token based on the auth type"""

        if isinstance(self.auth, tuple):
            response = auth_token_create.sync(
                client=self.__client,
                form_data=models.TokenObtainPair.from_dict(
                    {"username": self.auth[0], "password": self.auth[1]}
                ),
                multipart_data=UNSET,
                json_body=UNSET,
            )
        else:
            response = auth_token_retrieve.sync(
                client=self.__client.with_auth(HTTPSPNEGOAuth())
            )
        return response.refresh

    def __get_access_token(self) -> str:
        """Get new access token using the refresh token"""

        try:
            response = auth_token_refresh_create.sync(
                client=self.__client,
                form_data=models.TokenRefresh.from_dict(
                    {"refresh": self.refresh_token}
                ),
                multipart_data=UNSET,
                json_body=UNSET,
            )
        except requests.HTTPError:

            # expired refresh token, renew it and try again
            self.refresh_token = self.__get_refresh_token()
            response = auth_token_refresh_create.sync(
                client=self.__client,
                form_data=models.TokenRefresh.from_dict(
                    {"refresh": self.refresh_token}
                ),
                multipart_data=UNSET,
                json_body=UNSET,
            )

        return response.access

    def __get_client_with_new_access_token(self) -> AuthenticatedClient:
        """Create a new client with refreshed access token"""

        return self.__client.with_headers(
            {"Authorization": f"Bearer {self.__get_access_token()}"}
        )


class SessionOperationsGroup:
    """
    Group of the CRUD and extra operations for one specific resource
    """

    def __init__(
        self,
        client: Callable,
        resource_name: str,
        allowed_operations: List[str] = ALL_SESSION_OPERATIONS,
        subresources: Dict[str, dict] = None,
    ):
        self.client = client
        self.resource_name = resource_name
        self.allowed_operations = allowed_operations

        if subresources is None:
            subresources = {}

        # Create a session operation group for each subresource with respective
        # allowed session operations
        for subresource_name, subresource_metadata in subresources.items():
            setattr(
                self,
                subresource_name,
                SessionOperationsGroup(
                    client,
                    resource_name=f"{resource_name}_{subresource_name}",
                    **subresource_metadata,
                ),
            )

    def __raise_operation_unsupported(self, operation_name: str):
        """Operation unsupported exception shortcut"""

        raise OperationUnsupported(
            f'Operation "{operation_name}" is not supported for the '
            f'"{self.resource_name}" resource.'
        )

    def __raise_undefined_request_body(self, operation_name: str):
        """Undefined request body shortcut"""

        raise UndefinedRequestBody(
            f'The request body for the resource "{self.resource_name}" '
            f'and the operation "{operation_name}" is not defined.'
        )

    def __get_method_module(self, resource_name: str, method: str) -> ModuleType:
        # import endpoint module based on a method
        return importlib.import_module(
            f"{OSIDB_BINDINGS_API_PATH}.osidb_api_{OSIDB_API_VERSION}_{resource_name}_{method}",
            package="osidb_bindings",
        )

    # CRUD operations

    def retrieve(self, id, *args, **kwargs):
        if "retrieve" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="retrieve"
            )
            sync_fn = get_sync_function(method_module)
            return sync_fn(id, *args, client=self.client(), **kwargs)
        else:
            self.__raise_operation_unsupported("retrieve")

    def retrieve_list(self, *args, **kwargs):
        if "list" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="list"
            )
            sync_fn = get_sync_function(method_module)
            response = sync_fn(*args, client=self.client(), **kwargs)
            return Paginator.make_response_iterable(
                response, self.retrieve_list, *args, **kwargs
            )
        else:
            self.__raise_operation_unsupported("retrieve_list")

    def create(self, form_data: Dict[str, Any], *args, **kwargs):
        if "create" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="create"
            )
            model = getattr(method_module, "REQUEST_BODY_TYPE", None)
            if model is None:
                self.__raise_undefined_request_body("create")

            transformed_data = model.from_dict(form_data)
            sync_fn = get_sync_function(method_module)
            return sync_fn(
                *args,
                client=self.client(),
                form_data=transformed_data,
                multipart_data=UNSET,
                json_body=UNSET,
                **kwargs,
            )
        else:
            self.__raise_operation_unsupported("create")

    def update(self, id, form_data: Dict[str, Any], *args, **kwargs):
        if "update" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="update"
            )
            model = getattr(method_module, "REQUEST_BODY_TYPE", None)
            if model is None:
                self.__raise_undefined_request_body("update")

            transformed_data = model.from_dict(form_data)
            sync_fn = get_sync_function(method_module)
            return sync_fn(
                id,
                *args,
                client=self.client(),
                form_data=transformed_data,
                multipart_data=UNSET,
                json_body=UNSET,
                **kwargs,
            )
        else:
            self.__raise_operation_unsupported("update")

    def delete(self, id, *args, **kwargs):
        if "destroy" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="destroy"
            )
            sync_fn = get_sync_function(method_module)
            return sync_fn(
                id,
                *args,
                client=self.client(),
                **kwargs,
            )
        else:
            self.__raise_operation_unsupported("delete")

    # Extra operations

    def search(self, searched_text: str):
        if "search" in self.allowed_operations:
            method_module = self.__get_method_module(
                resource_name=self.resource_name, method="list"
            )
            sync_fn = get_sync_function(method_module)
            return sync_fn(client=self.client(), search=searched_text)
        else:
            self.__raise_operation_unsupported("search")

    def retrieve_list_iterator(self, *args, **kwargs):
        if "list" in self.allowed_operations:
            paginator = Paginator(
                *args,
                retrieve_list_fn=self.retrieve_list,
                **kwargs,
            )

            for page in paginator:
                for resource in page.results:
                    yield resource
        else:
            self.__raise_operation_unsupported("retrieve_list")



import ssl
from typing import Dict, Tuple, Type, Union

import attr
import requests


@attr.s(auto_attribs=True)
class Client:
    """A class for keeping track of data related to the API"""

    base_url: str
    cookies: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    headers: Dict[str, str] = attr.ib(factory=dict, kw_only=True)
    timeout: float = attr.ib(300.0, kw_only=True)
    verify_ssl: Union[str, bool, ssl.SSLContext] = attr.ib(True, kw_only=True)

    def get_headers(self) -> Dict[str, str]:
        """Get headers to be used in all endpoints"""
        return {**self.headers}

    def with_headers(self, headers: Dict[str, str]) -> "Client":
        """Get a new client matching this one with additional headers"""
        return attr.evolve(self, headers={**self.headers, **headers})

    def get_cookies(self) -> Dict[str, str]:
        return {**self.cookies}

    def with_cookies(self, cookies: Dict[str, str]) -> "Client":
        """Get a new client matching this one with additional cookies"""
        return attr.evolve(self, cookies={**self.cookies, **cookies})

    def get_timeout(self) -> float:
        return self.timeout

    def with_timeout(self, timeout: float) -> "Client":
        """Get a new client matching this one with a new timeout (in seconds)"""
        return attr.evolve(self, timeout=timeout)


@attr.s(auto_attribs=True)
class AuthenticatedClient(Client):
    """A Client which has been authenticated for use on secured endpoints"""

    auth: Union[None, Tuple[str, str], Type[requests.auth.AuthBase]] = attr.ib(
        None, kw_only=True
    )

    def get_auth(self) -> Union[None, Tuple[str, str], Type[requests.auth.AuthBase]]:
        return self.auth

    def with_auth(
        self, auth: Union[None, Tuple[str, str], Type[requests.auth.AuthBase]]
    ) -> "Client":
        """Get a new client matching this one with a new auth method"""
        return attr.evolve(self, auth=auth)



from .taskman_api_v1_group_create import *
from .taskman_api_v1_group_retrieve import *
from .taskman_api_v1_group_update import *
from .taskman_api_v1_task_assignee_retrieve import *
from .taskman_api_v1_task_assignee_update import *
from .taskman_api_v1_task_comment_create import *
from .taskman_api_v1_task_comment_update import *
from .taskman_api_v1_task_flaw_create import *
from .taskman_api_v1_task_flaw_retrieve import *
from .taskman_api_v1_task_flaw_update import *
from .taskman_api_v1_task_retrieve import *
from .taskman_api_v1_task_status_update import *
from .taskman_api_v1_task_unassigned_retrieve import *
from .taskman_healthy_retrieve import *



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..types import UNSET, OSIDBModel

T = TypeVar("T", bound="SupportedProducts")


@attr.s(auto_attribs=True)
class SupportedProducts(OSIDBModel):
    """ """

    name: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        supported_products = cls(
            name=name,
        )

        supported_products.additional_properties = d
        return supported_products

    @staticmethod
    def get_fields():
        return {
            "name": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.jira_issue import JiraIssue
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="JiraIssueQueryResult")


@attr.s(auto_attribs=True)
class JiraIssueQueryResult(OSIDBModel):
    """ """

    total: int
    issues: List[JiraIssue]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total = self.total
        issues: List[Dict[str, Any]] = UNSET
        if not isinstance(self.issues, Unset):
            issues = []
            for issues_item_data in self.issues:
                issues_item: Dict[str, Any] = UNSET
                if not isinstance(issues_item_data, Unset):
                    issues_item = issues_item_data.to_dict()

                issues.append(issues_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if total is not UNSET:
            field_dict["total"] = total
        if issues is not UNSET:
            field_dict["issues"] = issues

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total = d.pop("total", UNSET)

        issues = []
        _issues = d.pop("issues", UNSET)
        if _issues is UNSET:
            issues = UNSET
        else:
            for issues_item_data in _issues or []:
                _issues_item = issues_item_data
                issues_item: JiraIssue
                if isinstance(_issues_item, Unset):
                    issues_item = UNSET
                else:
                    issues_item = JiraIssue.from_dict(_issues_item)

                issues.append(issues_item)

        jira_issue_query_result = cls(
            total=total,
            issues=issues,
        )

        jira_issue_query_result.additional_properties = d
        return jira_issue_query_result

    @staticmethod
    def get_fields():
        return {
            "total": int,
            "issues": List[JiraIssue],
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.status_enum import StatusEnum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="CVEv5Versions")


@attr.s(auto_attribs=True)
class CVEv5Versions(OSIDBModel):
    """CVEv5 Package Version Serializer"""

    version: str
    status: StatusEnum
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        version = self.version
        status: str = UNSET
        if not isinstance(self.status, Unset):

            status = StatusEnum(self.status).value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if version is not UNSET:
            field_dict["version"] = version
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        version = d.pop("version", UNSET)

        _status = d.pop("status", UNSET)
        status: StatusEnum
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = StatusEnum(_status)

        cv_ev_5_versions = cls(
            version=version,
            status=status,
        )

        cv_ev_5_versions.additional_properties = d
        return cv_ev_5_versions

    @staticmethod
    def get_fields():
        return {
            "version": str,
            "status": StatusEnum,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from .osidb_api_v1_affects_create import *
from .osidb_api_v1_affects_destroy import *
from .osidb_api_v1_affects_list import *
from .osidb_api_v1_affects_retrieve import *
from .osidb_api_v1_affects_update import *
from .osidb_api_v1_flaws_comments_create import *
from .osidb_api_v1_flaws_comments_list import *
from .osidb_api_v1_flaws_comments_retrieve import *
from .osidb_api_v1_flaws_create import *
from .osidb_api_v1_flaws_list import *
from .osidb_api_v1_flaws_references_create import *
from .osidb_api_v1_flaws_references_destroy import *
from .osidb_api_v1_flaws_references_list import *
from .osidb_api_v1_flaws_references_retrieve import *
from .osidb_api_v1_flaws_references_update import *
from .osidb_api_v1_flaws_retrieve import *
from .osidb_api_v1_flaws_update import *
from .osidb_api_v1_manifest_retrieve import *
from .osidb_api_v1_schema_retrieve import *
from .osidb_api_v1_status_retrieve import *
from .osidb_api_v1_trackers_list import *
from .osidb_api_v1_trackers_retrieve import *
from .osidb_healthy_retrieve import *
from .osidb_whoami_retrieve import *



from enum import Enum


class FlawPostClassificationState(str, Enum):
    DRAFT = "DRAFT"
    NEW = "NEW"
    ANALYSIS = "ANALYSIS"
    REVIEW = "REVIEW"
    FIX = "FIX"
    DONE = "DONE"

    def __str__(self) -> str:
        return str(self.value)



import datetime
import json
from typing import Any, Dict, List, Optional, Tuple, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.affect_meta_attr import AffectMetaAttr
from ..models.affect_type import AffectType
from ..models.affectedness_enum import AffectednessEnum
from ..models.blank_enum import BlankEnum
from ..models.impact_enum import ImpactEnum
from ..models.resolution_enum import ResolutionEnum
from ..models.tracker import Tracker
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="Affect")


@attr.s(auto_attribs=True)
class Affect(OSIDBModel):
    """Affect serializer"""

    uuid: str
    ps_module: str
    ps_component: str
    trackers: List[Tracker]
    meta_attr: AffectMetaAttr
    delegated_resolution: str
    embargoed: bool
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    flaw: Optional[str]
    type: Union[Unset, AffectType] = UNSET
    affectedness: Union[AffectednessEnum, BlankEnum, Unset] = UNSET
    resolution: Union[BlankEnum, ResolutionEnum, Unset] = UNSET
    impact: Union[BlankEnum, ImpactEnum, Unset] = UNSET
    cvss2: Union[Unset, str] = UNSET
    cvss2_score: Union[Unset, None, float] = UNSET
    cvss3: Union[Unset, str] = UNSET
    cvss3_score: Union[Unset, None, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        uuid = self.uuid
        ps_module = self.ps_module
        ps_component = self.ps_component
        trackers: List[Dict[str, Any]] = UNSET
        if not isinstance(self.trackers, Unset):
            trackers = []
            for trackers_item_data in self.trackers:
                trackers_item: Dict[str, Any] = UNSET
                if not isinstance(trackers_item_data, Unset):
                    trackers_item = trackers_item_data.to_dict()

                trackers.append(trackers_item)

        meta_attr: Dict[str, Any] = UNSET
        if not isinstance(self.meta_attr, Unset):
            meta_attr = self.meta_attr.to_dict()

        delegated_resolution = self.delegated_resolution
        embargoed = self.embargoed
        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        flaw = self.flaw
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):

            type = AffectType(self.type).value

        affectedness: Union[Unset, str]
        if isinstance(self.affectedness, Unset):
            affectedness = UNSET
        elif isinstance(self.affectedness, AffectednessEnum):
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):

                affectedness = AffectednessEnum(self.affectedness).value

        else:
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):

                affectedness = BlankEnum(self.affectedness).value

        resolution: Union[Unset, str]
        if isinstance(self.resolution, Unset):
            resolution = UNSET
        elif isinstance(self.resolution, ResolutionEnum):
            resolution = UNSET
            if not isinstance(self.resolution, Unset):

                resolution = ResolutionEnum(self.resolution).value

        else:
            resolution = UNSET
            if not isinstance(self.resolution, Unset):

                resolution = BlankEnum(self.resolution).value

        impact: Union[Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = ImpactEnum(self.impact).value

        else:
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = BlankEnum(self.impact).value

        cvss2 = self.cvss2
        cvss2_score = self.cvss2_score
        cvss3 = self.cvss3
        cvss3_score = self.cvss3_score

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if ps_module is not UNSET:
            field_dict["ps_module"] = ps_module
        if ps_component is not UNSET:
            field_dict["ps_component"] = ps_component
        if trackers is not UNSET:
            field_dict["trackers"] = trackers
        if meta_attr is not UNSET:
            field_dict["meta_attr"] = meta_attr
        if delegated_resolution is not UNSET:
            field_dict["delegated_resolution"] = delegated_resolution
        if embargoed is not UNSET:
            field_dict["embargoed"] = embargoed
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if updated_dt is not UNSET:
            field_dict["updated_dt"] = updated_dt
        if flaw is not UNSET:
            field_dict["flaw"] = flaw
        if type is not UNSET:
            field_dict["type"] = type
        if affectedness is not UNSET:
            field_dict["affectedness"] = affectedness
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if impact is not UNSET:
            field_dict["impact"] = impact
        if cvss2 is not UNSET:
            field_dict["cvss2"] = cvss2
        if cvss2_score is not UNSET:
            field_dict["cvss2_score"] = cvss2_score
        if cvss3 is not UNSET:
            field_dict["cvss3"] = cvss3
        if cvss3_score is not UNSET:
            field_dict["cvss3_score"] = cvss3_score

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        uuid = self.uuid if self.uuid is UNSET else (None, str(self.uuid), "text/plain")
        ps_module = (
            self.ps_module
            if self.ps_module is UNSET
            else (None, str(self.ps_module), "text/plain")
        )
        ps_component = (
            self.ps_component
            if self.ps_component is UNSET
            else (None, str(self.ps_component), "text/plain")
        )
        trackers: Union[Unset, Tuple[None, str, str]] = UNSET
        if not isinstance(self.trackers, Unset):
            _temp_trackers = []
            for trackers_item_data in self.trackers:
                trackers_item: Dict[str, Any] = UNSET
                if not isinstance(trackers_item_data, Unset):
                    trackers_item = trackers_item_data.to_dict()

                _temp_trackers.append(trackers_item)
            trackers = (None, json.dumps(_temp_trackers), "application/json")

        meta_attr: Union[Unset, Tuple[None, str, str]] = UNSET
        if not isinstance(self.meta_attr, Unset):
            meta_attr = (None, json.dumps(self.meta_attr.to_dict()), "application/json")

        delegated_resolution = (
            self.delegated_resolution
            if self.delegated_resolution is UNSET
            else (None, str(self.delegated_resolution), "text/plain")
        )
        embargoed = (
            self.embargoed
            if self.embargoed is UNSET
            else (None, str(self.embargoed), "text/plain")
        )
        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        flaw = self.flaw if self.flaw is UNSET else (None, str(self.flaw), "text/plain")
        type: Union[Unset, Tuple[None, str, str]] = UNSET
        if not isinstance(self.type, Unset):

            type = AffectType(self.type).value

        affectedness: Union[Unset, str]
        if isinstance(self.affectedness, Unset):
            affectedness = UNSET
        elif isinstance(self.affectedness, AffectednessEnum):
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):

                affectedness = AffectednessEnum(self.affectedness).value

        else:
            affectedness = UNSET
            if not isinstance(self.affectedness, Unset):

                affectedness = BlankEnum(self.affectedness).value

        resolution: Union[Unset, str]
        if isinstance(self.resolution, Unset):
            resolution = UNSET
        elif isinstance(self.resolution, ResolutionEnum):
            resolution = UNSET
            if not isinstance(self.resolution, Unset):

                resolution = ResolutionEnum(self.resolution).value

        else:
            resolution = UNSET
            if not isinstance(self.resolution, Unset):

                resolution = BlankEnum(self.resolution).value

        impact: Union[Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = ImpactEnum(self.impact).value

        else:
            impact = UNSET
            if not isinstance(self.impact, Unset):

                impact = BlankEnum(self.impact).value

        cvss2 = (
            self.cvss2 if self.cvss2 is UNSET else (None, str(self.cvss2), "text/plain")
        )
        cvss2_score = (
            self.cvss2_score
            if self.cvss2_score is UNSET
            else (None, str(self.cvss2_score), "text/plain")
        )
        cvss3 = (
            self.cvss3 if self.cvss3 is UNSET else (None, str(self.cvss3), "text/plain")
        )
        cvss3_score = (
            self.cvss3_score
            if self.cvss3_score is UNSET
            else (None, str(self.cvss3_score), "text/plain")
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                key: (None, str(value), "text/plain")
                for key, value in self.additional_properties.items()
            }
        )
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if ps_module is not UNSET:
            field_dict["ps_module"] = ps_module
        if ps_component is not UNSET:
            field_dict["ps_component"] = ps_component
        if trackers is not UNSET:
            field_dict["trackers"] = trackers
        if meta_attr is not UNSET:
            field_dict["meta_attr"] = meta_attr
        if delegated_resolution is not UNSET:
            field_dict["delegated_resolution"] = delegated_resolution
        if embargoed is not UNSET:
            field_dict["embargoed"] = embargoed
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if updated_dt is not UNSET:
            field_dict["updated_dt"] = updated_dt
        if flaw is not UNSET:
            field_dict["flaw"] = flaw
        if type is not UNSET:
            field_dict["type"] = type
        if affectedness is not UNSET:
            field_dict["affectedness"] = affectedness
        if resolution is not UNSET:
            field_dict["resolution"] = resolution
        if impact is not UNSET:
            field_dict["impact"] = impact
        if cvss2 is not UNSET:
            field_dict["cvss2"] = cvss2
        if cvss2_score is not UNSET:
            field_dict["cvss2_score"] = cvss2_score
        if cvss3 is not UNSET:
            field_dict["cvss3"] = cvss3
        if cvss3_score is not UNSET:
            field_dict["cvss3_score"] = cvss3_score

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        uuid = d.pop("uuid", UNSET)

        ps_module = d.pop("ps_module", UNSET)

        ps_component = d.pop("ps_component", UNSET)

        trackers = []
        _trackers = d.pop("trackers", UNSET)
        if _trackers is UNSET:
            trackers = UNSET
        else:
            for trackers_item_data in _trackers or []:
                _trackers_item = trackers_item_data
                trackers_item: Tracker
                if isinstance(_trackers_item, Unset):
                    trackers_item = UNSET
                else:
                    trackers_item = Tracker.from_dict(_trackers_item)

                trackers.append(trackers_item)

        _meta_attr = d.pop("meta_attr", UNSET)
        meta_attr: AffectMetaAttr
        if isinstance(_meta_attr, Unset):
            meta_attr = UNSET
        else:
            meta_attr = AffectMetaAttr.from_dict(_meta_attr)

        delegated_resolution = d.pop("delegated_resolution", UNSET)

        embargoed = d.pop("embargoed", UNSET)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        flaw = d.pop("flaw", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[Unset, AffectType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = AffectType(_type)

        def _parse_affectedness(
            data: object,
        ) -> Union[AffectednessEnum, BlankEnum, Unset]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _affectedness_type_0 = data
                affectedness_type_0: Union[Unset, AffectednessEnum]
                if isinstance(_affectedness_type_0, Unset):
                    affectedness_type_0 = UNSET
                else:
                    affectedness_type_0 = AffectednessEnum(_affectedness_type_0)

                return affectedness_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _affectedness_type_1 = data
            affectedness_type_1: Union[Unset, BlankEnum]
            if isinstance(_affectedness_type_1, Unset):
                affectedness_type_1 = UNSET
            else:
                affectedness_type_1 = BlankEnum(_affectedness_type_1)

            return affectedness_type_1

        affectedness = _parse_affectedness(d.pop("affectedness", UNSET))

        def _parse_resolution(data: object) -> Union[BlankEnum, ResolutionEnum, Unset]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _resolution_type_0 = data
                resolution_type_0: Union[Unset, ResolutionEnum]
                if isinstance(_resolution_type_0, Unset):
                    resolution_type_0 = UNSET
                else:
                    resolution_type_0 = ResolutionEnum(_resolution_type_0)

                return resolution_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _resolution_type_1 = data
            resolution_type_1: Union[Unset, BlankEnum]
            if isinstance(_resolution_type_1, Unset):
                resolution_type_1 = UNSET
            else:
                resolution_type_1 = BlankEnum(_resolution_type_1)

            return resolution_type_1

        resolution = _parse_resolution(d.pop("resolution", UNSET))

        def _parse_impact(data: object) -> Union[BlankEnum, ImpactEnum, Unset]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_0 = data
                impact_type_0: Union[Unset, ImpactEnum]
                if isinstance(_impact_type_0, Unset):
                    impact_type_0 = UNSET
                else:
                    impact_type_0 = ImpactEnum(_impact_type_0)

                return impact_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _impact_type_1 = data
            impact_type_1: Union[Unset, BlankEnum]
            if isinstance(_impact_type_1, Unset):
                impact_type_1 = UNSET
            else:
                impact_type_1 = BlankEnum(_impact_type_1)

            return impact_type_1

        impact = _parse_impact(d.pop("impact", UNSET))

        cvss2 = d.pop("cvss2", UNSET)

        cvss2_score = d.pop("cvss2_score", UNSET)

        cvss3 = d.pop("cvss3", UNSET)

        cvss3_score = d.pop("cvss3_score", UNSET)

        affect = cls(
            uuid=uuid,
            ps_module=ps_module,
            ps_component=ps_component,
            trackers=trackers,
            meta_attr=meta_attr,
            delegated_resolution=delegated_resolution,
            embargoed=embargoed,
            created_dt=created_dt,
            updated_dt=updated_dt,
            flaw=flaw,
            type=type,
            affectedness=affectedness,
            resolution=resolution,
            impact=impact,
            cvss2=cvss2,
            cvss2_score=cvss2_score,
            cvss3=cvss3,
            cvss3_score=cvss3_score,
        )

        affect.additional_properties = d
        return affect

    @staticmethod
    def get_fields():
        return {
            "uuid": str,
            "ps_module": str,
            "ps_component": str,
            "trackers": List[Tracker],
            "meta_attr": AffectMetaAttr,
            "delegated_resolution": str,
            "embargoed": bool,
            "created_dt": datetime.datetime,
            "updated_dt": datetime.datetime,
            "flaw": str,
            "type": AffectType,
            "affectedness": Union[AffectednessEnum, BlankEnum],
            "resolution": Union[BlankEnum, ResolutionEnum],
            "impact": Union[BlankEnum, ImpactEnum],
            "cvss2": str,
            "cvss2_score": float,
            "cvss3": str,
            "cvss3_score": float,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ExploitOnlyReportDataSourceEnum(str, Enum):
    CISA = "CISA"
    METASPLOIT = "Metasploit"
    EXPLOIT_DB = "Exploit-DB"

    def __str__(self) -> str:
        return str(self.value)



from .osim_api_v1_workflows_adjust_create import *
from .osim_api_v1_workflows_retrieve import *
from .osim_api_v1_workflows_retrieve_2 import *
from .osim_healthy_retrieve import *
from .osim_retrieve import *



from typing import Any, Dict, Optional

import requests

from ...client import AuthenticatedClient
from ...models.exploits_api_v1_report_pending_retrieve_response_200 import (
    ExploitsApiV1ReportPendingRetrieveResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}


def _get_kwargs(
    *,
    client: AuthenticatedClient,
) -> Dict[str, Any]:
    url = "{}/exploits/api/v1/report/pending".format(
        client.base_url,
    )

    headers: Dict[str, Any] = client.get_headers()

    return {
        "url": url,
        "headers": headers,
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[ExploitsApiV1ReportPendingRetrieveResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: ExploitsApiV1ReportPendingRetrieveResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = ExploitsApiV1ReportPendingRetrieveResponse200.from_dict(
                _response_200
            )

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[ExploitsApiV1ReportPendingRetrieveResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[ExploitsApiV1ReportPendingRetrieveResponse200]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
) -> Optional[ExploitsApiV1ReportPendingRetrieveResponse200]:
    """API endpoint for getting a report of pending actions for Incident Response.

    Format of results:
    ```
    {
      \"pending_actions\": [<List of affects requiring action>],
      \"pending_actions_count\": <Number of affects requiring action>,
    }
    ```

    **NOTE:** No pagination is performed on this endpoint as it is expected that the size of
              the list of pending actions will be mostly stable. Also, the paging cannot be done on
              the query level, as additional analysis of every exploit is required before a decision
              to include it in this report is done."""

    return sync_detailed(
        client=client,
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..types import UNSET, OSIDBModel

T = TypeVar("T", bound="EPSS")


@attr.s(auto_attribs=True)
class EPSS(OSIDBModel):
    """ """

    cve: str
    epss: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cve = self.cve
        epss = self.epss

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if cve is not UNSET:
            field_dict["cve"] = cve
        if epss is not UNSET:
            field_dict["epss"] = epss

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cve = d.pop("cve", UNSET)

        epss = d.pop("epss", UNSET)

        epss = cls(
            cve=cve,
            epss=epss,
        )

        epss.additional_properties = d
        return epss

    @staticmethod
    def get_fields():
        return {
            "cve": str,
            "epss": float,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class OsidbApiV1FlawsListOrderItem(str, Enum):
    VALUE_0 = "-affects__affectedness"
    VALUE_1 = "-affects__created_dt"
    VALUE_2 = "-affects__cvss2"
    VALUE_3 = "-affects__cvss2_score"
    VALUE_4 = "-affects__cvss3"
    VALUE_5 = "-affects__cvss3_score"
    VALUE_6 = "-affects__impact"
    VALUE_7 = "-affects__ps_component"
    VALUE_8 = "-affects__ps_module"
    VALUE_9 = "-affects__resolution"
    VALUE_10 = "-affects__trackers__created_dt"
    VALUE_11 = "-affects__trackers__errata__advisory_name"
    VALUE_12 = "-affects__trackers__external_system_id"
    VALUE_13 = "-affects__trackers__ps_update_stream"
    VALUE_14 = "-affects__trackers__resolution"
    VALUE_15 = "-affects__trackers__status"
    VALUE_16 = "-affects__trackers__type"
    VALUE_17 = "-affects__trackers__updated_dt"
    VALUE_18 = "-affects__trackers__uuid"
    VALUE_19 = "-affects__type"
    VALUE_20 = "-affects__updated_dt"
    VALUE_21 = "-affects__uuid"
    VALUE_22 = "-component"
    VALUE_23 = "-created_dt"
    VALUE_24 = "-cve_id"
    VALUE_25 = "-cvss2"
    VALUE_26 = "-cvss2_score"
    VALUE_27 = "-cvss3"
    VALUE_28 = "-cvss3_score"
    VALUE_29 = "-cwe_id"
    VALUE_30 = "-impact"
    VALUE_31 = "-is_major_incident"
    VALUE_32 = "-nvd_cvss2"
    VALUE_33 = "-nvd_cvss3"
    VALUE_34 = "-reported_dt"
    VALUE_35 = "-source"
    VALUE_36 = "-type"
    VALUE_37 = "-unembargo_dt"
    VALUE_38 = "-updated_dt"
    VALUE_39 = "-uuid"
    AFFECTS_AFFECTEDNESS = "affects__affectedness"
    AFFECTS_CREATED_DT = "affects__created_dt"
    AFFECTS_CVSS2 = "affects__cvss2"
    AFFECTS_CVSS2_SCORE = "affects__cvss2_score"
    AFFECTS_CVSS3 = "affects__cvss3"
    AFFECTS_CVSS3_SCORE = "affects__cvss3_score"
    AFFECTS_IMPACT = "affects__impact"
    AFFECTS_PS_COMPONENT = "affects__ps_component"
    AFFECTS_PS_MODULE = "affects__ps_module"
    AFFECTS_RESOLUTION = "affects__resolution"
    AFFECTS_TRACKERS_CREATED_DT = "affects__trackers__created_dt"
    AFFECTS_TRACKERS_ERRATA_ADVISORY_NAME = "affects__trackers__errata__advisory_name"
    AFFECTS_TRACKERS_EXTERNAL_SYSTEM_ID = "affects__trackers__external_system_id"
    AFFECTS_TRACKERS_PS_UPDATE_STREAM = "affects__trackers__ps_update_stream"
    AFFECTS_TRACKERS_RESOLUTION = "affects__trackers__resolution"
    AFFECTS_TRACKERS_STATUS = "affects__trackers__status"
    AFFECTS_TRACKERS_TYPE = "affects__trackers__type"
    AFFECTS_TRACKERS_UPDATED_DT = "affects__trackers__updated_dt"
    AFFECTS_TRACKERS_UUID = "affects__trackers__uuid"
    AFFECTS_TYPE = "affects__type"
    AFFECTS_UPDATED_DT = "affects__updated_dt"
    AFFECTS_UUID = "affects__uuid"
    COMPONENT = "component"
    CREATED_DT = "created_dt"
    CVE_ID = "cve_id"
    CVSS2 = "cvss2"
    CVSS2_SCORE = "cvss2_score"
    CVSS3 = "cvss3"
    CVSS3_SCORE = "cvss3_score"
    CWE_ID = "cwe_id"
    IMPACT = "impact"
    IS_MAJOR_INCIDENT = "is_major_incident"
    NVD_CVSS2 = "nvd_cvss2"
    NVD_CVSS3 = "nvd_cvss3"
    REPORTED_DT = "reported_dt"
    SOURCE = "source"
    TYPE = "type"
    UNEMBARGO_DT = "unembargo_dt"
    UPDATED_DT = "updated_dt"
    UUID = "uuid"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.jira_user import JiraUser
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="TaskmanApiV1TaskCommentCreateResponse200")


@attr.s(auto_attribs=True)
class TaskmanApiV1TaskCommentCreateResponse200(OSIDBModel):
    """ """

    id: int
    author: JiraUser
    body: str
    created: datetime.datetime
    updated: datetime.datetime
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        author: Dict[str, Any] = UNSET
        if not isinstance(self.author, Unset):
            author = self.author.to_dict()

        body = self.body
        created: str = UNSET
        if not isinstance(self.created, Unset):
            created = self.created.isoformat()

        updated: str = UNSET
        if not isinstance(self.updated, Unset):
            updated = self.updated.isoformat()

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env
        revision = self.revision
        version = self.version

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if id is not UNSET:
            field_dict["id"] = id
        if author is not UNSET:
            field_dict["author"] = author
        if body is not UNSET:
            field_dict["body"] = body
        if created is not UNSET:
            field_dict["created"] = created
        if updated is not UNSET:
            field_dict["updated"] = updated
        if dt is not UNSET:
            field_dict["dt"] = dt
        if env is not UNSET:
            field_dict["env"] = env
        if revision is not UNSET:
            field_dict["revision"] = revision
        if version is not UNSET:
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        _author = d.pop("author", UNSET)
        author: JiraUser
        if isinstance(_author, Unset):
            author = UNSET
        else:
            author = JiraUser.from_dict(_author)

        body = d.pop("body", UNSET)

        _created = d.pop("created", UNSET)
        created: datetime.datetime
        if isinstance(_created, Unset):
            created = UNSET
        else:
            created = isoparse(_created)

        _updated = d.pop("updated", UNSET)
        updated: datetime.datetime
        if isinstance(_updated, Unset):
            updated = UNSET
        else:
            updated = isoparse(_updated)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        taskman_api_v1_task_comment_create_response_200 = cls(
            id=id,
            author=author,
            body=body,
            created=created,
            updated=updated,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        taskman_api_v1_task_comment_create_response_200.additional_properties = d
        return taskman_api_v1_task_comment_create_response_200

    @staticmethod
    def get_fields():
        return {
            "id": int,
            "author": JiraUser,
            "body": str,
            "created": datetime.datetime,
            "updated": datetime.datetime,
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..types import UNSET, OSIDBModel

T = TypeVar("T", bound="TokenObtainPair")


@attr.s(auto_attribs=True)
class TokenObtainPair(OSIDBModel):
    """ """

    username: str
    password: str
    access: str
    refresh: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        username = self.username
        password = self.password
        access = self.access
        refresh = self.refresh

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if username is not UNSET:
            field_dict["username"] = username
        if password is not UNSET:
            field_dict["password"] = password
        if access is not UNSET:
            field_dict["access"] = access
        if refresh is not UNSET:
            field_dict["refresh"] = refresh

        return field_dict

    def to_multipart(self) -> Dict[str, Any]:
        username = (
            self.username
            if self.username is UNSET
            else (None, str(self.username), "text/plain")
        )
        password = (
            self.password
            if self.password is UNSET
            else (None, str(self.password), "text/plain")
        )
        access = (
            self.access
            if self.access is UNSET
            else (None, str(self.access), "text/plain")
        )
        refresh = (
            self.refresh
            if self.refresh is UNSET
            else (None, str(self.refresh), "text/plain")
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                key: (None, str(value), "text/plain")
                for key, value in self.additional_properties.items()
            }
        )
        if username is not UNSET:
            field_dict["username"] = username
        if password is not UNSET:
            field_dict["password"] = password
        if access is not UNSET:
            field_dict["access"] = access
        if refresh is not UNSET:
            field_dict["refresh"] = refresh

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        username = d.pop("username", UNSET)

        password = d.pop("password", UNSET)

        access = d.pop("access", UNSET)

        refresh = d.pop("refresh", UNSET)

        token_obtain_pair = cls(
            username=username,
            password=password,
            access=access,
            refresh=refresh,
        )

        token_obtain_pair.additional_properties = d
        return token_obtain_pair

    @staticmethod
    def get_fields():
        return {
            "username": str,
            "password": str,
            "access": str,
            "refresh": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class OsidbApiV1SchemaRetrieveLang(str, Enum):
    AF = "af"
    AR = "ar"
    AR_DZ = "ar-dz"
    AST = "ast"
    AZ = "az"
    BE = "be"
    BG = "bg"
    BN = "bn"
    BR = "br"
    BS = "bs"
    CA = "ca"
    CS = "cs"
    CY = "cy"
    DA = "da"
    DE = "de"
    DSB = "dsb"
    EL = "el"
    EN = "en"
    EN_AU = "en-au"
    EN_GB = "en-gb"
    EO = "eo"
    ES = "es"
    ES_AR = "es-ar"
    ES_CO = "es-co"
    ES_MX = "es-mx"
    ES_NI = "es-ni"
    ES_VE = "es-ve"
    ET = "et"
    EU = "eu"
    FA = "fa"
    FI = "fi"
    FR = "fr"
    FY = "fy"
    GA = "ga"
    GD = "gd"
    GL = "gl"
    HE = "he"
    HI = "hi"
    HR = "hr"
    HSB = "hsb"
    HU = "hu"
    HY = "hy"
    IA = "ia"
    ID = "id"
    IG = "ig"
    IO = "io"
    IS = "is"
    IT = "it"
    JA = "ja"
    KA = "ka"
    KAB = "kab"
    KK = "kk"
    KM = "km"
    KN = "kn"
    KO = "ko"
    KY = "ky"
    LB = "lb"
    LT = "lt"
    LV = "lv"
    MK = "mk"
    ML = "ml"
    MN = "mn"
    MR = "mr"
    MY = "my"
    NB = "nb"
    NE = "ne"
    NL = "nl"
    NN = "nn"
    OS = "os"
    PA = "pa"
    PL = "pl"
    PT = "pt"
    PT_BR = "pt-br"
    RO = "ro"
    RU = "ru"
    SK = "sk"
    SL = "sl"
    SQ = "sq"
    SR = "sr"
    SR_LATN = "sr-latn"
    SV = "sv"
    SW = "sw"
    TA = "ta"
    TE = "te"
    TG = "tg"
    TH = "th"
    TK = "tk"
    TR = "tr"
    TT = "tt"
    UDM = "udm"
    UK = "uk"
    UR = "ur"
    UZ = "uz"
    VI = "vi"
    ZH_HANS = "zh-hans"
    ZH_HANT = "zh-hant"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, Optional

import requests

from ...client import AuthenticatedClient
from ...models.exploits_api_v1_report_date_retrieve_response_200 import (
    ExploitsApiV1ReportDateRetrieveResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}


def _get_kwargs(
    date: datetime.date,
    *,
    client: AuthenticatedClient,
) -> Dict[str, Any]:
    url = "{}/exploits/api/v1/report/date/{date}".format(
        client.base_url,
        date=date,
    )

    headers: Dict[str, Any] = client.get_headers()

    return {
        "url": url,
        "headers": headers,
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[ExploitsApiV1ReportDateRetrieveResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: ExploitsApiV1ReportDateRetrieveResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = ExploitsApiV1ReportDateRetrieveResponse200.from_dict(
                _response_200
            )

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[ExploitsApiV1ReportDateRetrieveResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    date: datetime.date,
    *,
    client: AuthenticatedClient,
) -> Response[ExploitsApiV1ReportDateRetrieveResponse200]:
    kwargs = _get_kwargs(
        date=date,
        client=client,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    date: datetime.date,
    *,
    client: AuthenticatedClient,
) -> Optional[ExploitsApiV1ReportDateRetrieveResponse200]:
    """API endpoint for getting date based report for Incident Response.

    Format of results:
    ```
    {
      \"cutoff_date\": <Date>,
      \"evaluated_cves\": <Number of new CVEs with exploits>,
      \"action_required\": [<List of affects requiring action>],
      \"no_action\": [<List of CVEs not requiring action with reason>],
      \"not_relevant\": [<List of CVEs which are not in the database with reason>],
    }
    ```

    **NOTE:** No pagination is performed on this endpoint as data is limited by date and is expected
              to be fairly small. Also, because data is broken into three categories it is not
              exactly obvious how to create pages."""

    return sync_detailed(
        date=date,
        client=client,
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item_data import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
)
from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item_error import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemError,
)
from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item_state import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
)
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="CollectorsApiV1StatusRetrieveResponse200CollectorsItem")


@attr.s(auto_attribs=True)
class CollectorsApiV1StatusRetrieveResponse200CollectorsItem(OSIDBModel):
    """ """

    data: Union[
        Unset, CollectorsApiV1StatusRetrieveResponse200CollectorsItemData
    ] = UNSET
    depends_on: Union[Unset, List[str]] = UNSET
    error: Union[
        Unset, None, CollectorsApiV1StatusRetrieveResponse200CollectorsItemError
    ] = UNSET
    is_complete: Union[Unset, bool] = UNSET
    data_models: Union[Unset, List[str]] = UNSET
    state: Union[
        Unset, CollectorsApiV1StatusRetrieveResponse200CollectorsItemState
    ] = UNSET
    updated_until: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data: Union[Unset, str] = UNSET
        if not isinstance(self.data, Unset):

            data = CollectorsApiV1StatusRetrieveResponse200CollectorsItemData(
                self.data
            ).value

        depends_on: Union[Unset, List[str]] = UNSET
        if not isinstance(self.depends_on, Unset):
            depends_on = self.depends_on

        error: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict() if self.error else None

        is_complete = self.is_complete
        data_models: Union[Unset, List[str]] = UNSET
        if not isinstance(self.data_models, Unset):
            data_models = self.data_models

        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):

            state = CollectorsApiV1StatusRetrieveResponse200CollectorsItemState(
                self.state
            ).value

        updated_until: Union[Unset, str] = UNSET
        if not isinstance(self.updated_until, Unset):
            updated_until = self.updated_until.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if data is not UNSET:
            field_dict["data"] = data
        if depends_on is not UNSET:
            field_dict["depends_on"] = depends_on
        if error is not UNSET:
            field_dict["error"] = error
        if is_complete is not UNSET:
            field_dict["is_complete"] = is_complete
        if data_models is not UNSET:
            field_dict["data_models"] = data_models
        if state is not UNSET:
            field_dict["state"] = state
        if updated_until is not UNSET:
            field_dict["updated_until"] = updated_until

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _data = d.pop("data", UNSET)
        data: Union[Unset, CollectorsApiV1StatusRetrieveResponse200CollectorsItemData]
        if isinstance(_data, Unset):
            data = UNSET
        else:
            data = CollectorsApiV1StatusRetrieveResponse200CollectorsItemData(_data)

        depends_on = cast(List[str], d.pop("depends_on", UNSET))

        _error = d.pop("error", UNSET)
        error: Union[
            Unset, None, CollectorsApiV1StatusRetrieveResponse200CollectorsItemError
        ]
        if _error is None:
            error = None
        elif isinstance(_error, Unset):
            error = UNSET
        else:
            error = (
                CollectorsApiV1StatusRetrieveResponse200CollectorsItemError.from_dict(
                    _error
                )
            )

        is_complete = d.pop("is_complete", UNSET)

        data_models = cast(List[str], d.pop("data_models", UNSET))

        _state = d.pop("state", UNSET)
        state: Union[Unset, CollectorsApiV1StatusRetrieveResponse200CollectorsItemState]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = CollectorsApiV1StatusRetrieveResponse200CollectorsItemState(_state)

        _updated_until = d.pop("updated_until", UNSET)
        updated_until: Union[Unset, datetime.datetime]
        if isinstance(_updated_until, Unset):
            updated_until = UNSET
        else:
            updated_until = isoparse(_updated_until)

        collectors_api_v1_status_retrieve_response_200_collectors_item = cls(
            data=data,
            depends_on=depends_on,
            error=error,
            is_complete=is_complete,
            data_models=data_models,
            state=state,
            updated_until=updated_until,
        )

        collectors_api_v1_status_retrieve_response_200_collectors_item.additional_properties = (
            d
        )
        return collectors_api_v1_status_retrieve_response_200_collectors_item

    @staticmethod
    def get_fields():
        return {
            "data": CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
            "depends_on": List[str],
            "error": CollectorsApiV1StatusRetrieveResponse200CollectorsItemError,
            "is_complete": bool,
            "data_models": List[str],
            "state": CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
            "updated_until": datetime.datetime,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Optional, Union

import requests

from ...client import AuthenticatedClient
from ...models.osidb_api_v1_affects_list_affectedness import (
    OsidbApiV1AffectsListAffectedness,
)
from ...models.osidb_api_v1_affects_list_flaw_impact import (
    OsidbApiV1AffectsListFlawImpact,
)
from ...models.osidb_api_v1_affects_list_flaw_source import (
    OsidbApiV1AffectsListFlawSource,
)
from ...models.osidb_api_v1_affects_list_flaw_type import OsidbApiV1AffectsListFlawType
from ...models.osidb_api_v1_affects_list_impact import OsidbApiV1AffectsListImpact
from ...models.osidb_api_v1_affects_list_order_item import (
    OsidbApiV1AffectsListOrderItem,
)
from ...models.osidb_api_v1_affects_list_resolution import (
    OsidbApiV1AffectsListResolution,
)
from ...models.osidb_api_v1_affects_list_response_200 import (
    OsidbApiV1AffectsListResponse200,
)
from ...models.osidb_api_v1_affects_list_trackers_type import (
    OsidbApiV1AffectsListTrackersType,
)
from ...models.osidb_api_v1_affects_list_type import OsidbApiV1AffectsListType
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {
    "affectedness": OsidbApiV1AffectsListAffectedness,
    "created_dt": datetime.datetime,
    "created_dt__date": datetime.date,
    "created_dt__date__gte": datetime.date,
    "created_dt__date__lte": datetime.date,
    "created_dt__gt": datetime.datetime,
    "created_dt__gte": datetime.datetime,
    "created_dt__lt": datetime.datetime,
    "created_dt__lte": datetime.datetime,
    "cvss2": str,
    "cvss2_score": float,
    "cvss2_score__gt": float,
    "cvss2_score__gte": float,
    "cvss2_score__lt": float,
    "cvss2_score__lte": float,
    "cvss3": str,
    "cvss3_score": float,
    "cvss3_score__gt": float,
    "cvss3_score__gte": float,
    "cvss3_score__lt": float,
    "cvss3_score__lte": float,
    "embargoed": bool,
    "exclude_fields": List[str],
    "flaw__component": str,
    "flaw__created_dt": datetime.datetime,
    "flaw__created_dt__date": datetime.date,
    "flaw__created_dt__date__gte": datetime.date,
    "flaw__created_dt__date__lte": datetime.date,
    "flaw__created_dt__gt": datetime.datetime,
    "flaw__created_dt__gte": datetime.datetime,
    "flaw__created_dt__lt": datetime.datetime,
    "flaw__created_dt__lte": datetime.datetime,
    "flaw__cve_id": str,
    "flaw__cvss2": str,
    "flaw__cvss2_score": float,
    "flaw__cvss2_score__gt": float,
    "flaw__cvss2_score__gte": float,
    "flaw__cvss2_score__lt": float,
    "flaw__cvss2_score__lte": float,
    "flaw__cvss3": str,
    "flaw__cvss3_score": float,
    "flaw__cvss3_score__gt": float,
    "flaw__cvss3_score__gte": float,
    "flaw__cvss3_score__lt": float,
    "flaw__cvss3_score__lte": float,
    "flaw__cwe_id": str,
    "flaw__embargoed": bool,
    "flaw__impact": OsidbApiV1AffectsListFlawImpact,
    "flaw__is_major_incident": bool,
    "flaw__nvd_cvss2": str,
    "flaw__nvd_cvss3": str,
    "flaw__reported_dt": datetime.datetime,
    "flaw__reported_dt__date": datetime.date,
    "flaw__reported_dt__date__gte": datetime.date,
    "flaw__reported_dt__date__lte": datetime.date,
    "flaw__reported_dt__gt": datetime.datetime,
    "flaw__reported_dt__gte": datetime.datetime,
    "flaw__reported_dt__lt": datetime.datetime,
    "flaw__reported_dt__lte": datetime.datetime,
    "flaw__source": OsidbApiV1AffectsListFlawSource,
    "flaw__type": OsidbApiV1AffectsListFlawType,
    "flaw__unembargo_dt": datetime.datetime,
    "flaw__updated_dt": datetime.datetime,
    "flaw__updated_dt__date": datetime.date,
    "flaw__updated_dt__date__gte": datetime.date,
    "flaw__updated_dt__date__lte": datetime.date,
    "flaw__updated_dt__gt": datetime.datetime,
    "flaw__updated_dt__gte": datetime.datetime,
    "flaw__updated_dt__lt": datetime.datetime,
    "flaw__updated_dt__lte": datetime.datetime,
    "flaw__uuid": str,
    "impact": OsidbApiV1AffectsListImpact,
    "include_fields": List[str],
    "include_meta_attr": List[str],
    "limit": int,
    "offset": int,
    "order": List[OsidbApiV1AffectsListOrderItem],
    "ps_component": str,
    "ps_module": str,
    "resolution": OsidbApiV1AffectsListResolution,
    "trackers__created_dt": datetime.datetime,
    "trackers__created_dt__date": datetime.date,
    "trackers__created_dt__date__gte": datetime.date,
    "trackers__created_dt__date__lte": datetime.date,
    "trackers__created_dt__gt": datetime.datetime,
    "trackers__created_dt__gte": datetime.datetime,
    "trackers__created_dt__lt": datetime.datetime,
    "trackers__created_dt__lte": datetime.datetime,
    "trackers__embargoed": bool,
    "trackers__external_system_id": str,
    "trackers__ps_update_stream": str,
    "trackers__resolution": str,
    "trackers__status": str,
    "trackers__type": OsidbApiV1AffectsListTrackersType,
    "trackers__updated_dt": datetime.datetime,
    "trackers__updated_dt__date": datetime.date,
    "trackers__updated_dt__date__gte": datetime.date,
    "trackers__updated_dt__date__lte": datetime.date,
    "trackers__updated_dt__gt": datetime.datetime,
    "trackers__updated_dt__gte": datetime.datetime,
    "trackers__updated_dt__lt": datetime.datetime,
    "trackers__updated_dt__lte": datetime.datetime,
    "trackers__uuid": str,
    "type": OsidbApiV1AffectsListType,
    "updated_dt": datetime.datetime,
    "updated_dt__date": datetime.date,
    "updated_dt__date__gte": datetime.date,
    "updated_dt__date__lte": datetime.date,
    "updated_dt__gt": datetime.datetime,
    "updated_dt__gte": datetime.datetime,
    "updated_dt__lt": datetime.datetime,
    "updated_dt__lte": datetime.datetime,
    "uuid": str,
}


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss2_score_gt: Union[Unset, None, float] = UNSET,
    cvss2_score_gte: Union[Unset, None, float] = UNSET,
    cvss2_score_lt: Union[Unset, None, float] = UNSET,
    cvss2_score_lte: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cvss3_score_gt: Union[Unset, None, float] = UNSET,
    cvss3_score_gte: Union[Unset, None, float] = UNSET,
    cvss3_score_lt: Union[Unset, None, float] = UNSET,
    cvss3_score_lte: Union[Unset, None, float] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_component: Union[Unset, None, str] = UNSET,
    flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_cve_id: Union[Unset, None, str] = UNSET,
    flaw_cvss2: Union[Unset, None, str] = UNSET,
    flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cvss3: Union[Unset, None, str] = UNSET,
    flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cwe_id: Union[Unset, None, str] = UNSET,
    flaw_embargoed: Union[Unset, None, bool] = UNSET,
    flaw_impact: Union[Unset, None, OsidbApiV1AffectsListFlawImpact] = UNSET,
    flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_source: Union[Unset, None, OsidbApiV1AffectsListFlawSource] = UNSET,
    flaw_type: Union[Unset, None, OsidbApiV1AffectsListFlawType] = UNSET,
    flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_uuid: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1AffectsListOrderItem]] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    trackers_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_embargoed: Union[Unset, None, bool] = UNSET,
    trackers_external_system_id: Union[Unset, None, str] = UNSET,
    trackers_ps_update_stream: Union[Unset, None, str] = UNSET,
    trackers_resolution: Union[Unset, None, str] = UNSET,
    trackers_status: Union[Unset, None, str] = UNSET,
    trackers_type: Union[Unset, None, OsidbApiV1AffectsListTrackersType] = UNSET,
    trackers_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_uuid: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/osidb/api/v1/affects".format(
        client.base_url,
    )

    headers: Dict[str, Any] = client.get_headers()

    json_affectedness: Union[Unset, None, str] = UNSET
    if not isinstance(affectedness, Unset):

        json_affectedness = (
            OsidbApiV1AffectsListAffectedness(affectedness).value
            if affectedness
            else None
        )

    json_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt, Unset):
        json_created_dt = created_dt.isoformat() if created_dt else None

    json_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date, Unset):
        json_created_dt_date = created_dt_date.isoformat() if created_dt_date else None

    json_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date_gte, Unset):
        json_created_dt_date_gte = (
            created_dt_date_gte.isoformat() if created_dt_date_gte else None
        )

    json_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_date_lte, Unset):
        json_created_dt_date_lte = (
            created_dt_date_lte.isoformat() if created_dt_date_lte else None
        )

    json_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_gt, Unset):
        json_created_dt_gt = created_dt_gt.isoformat() if created_dt_gt else None

    json_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_gte, Unset):
        json_created_dt_gte = created_dt_gte.isoformat() if created_dt_gte else None

    json_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_lt, Unset):
        json_created_dt_lt = created_dt_lt.isoformat() if created_dt_lt else None

    json_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(created_dt_lte, Unset):
        json_created_dt_lte = created_dt_lte.isoformat() if created_dt_lte else None

    json_exclude_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_fields, Unset):
        if exclude_fields is None:
            json_exclude_fields = None
        else:
            json_exclude_fields = exclude_fields

    json_flaw_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt, Unset):
        json_flaw_created_dt = flaw_created_dt.isoformat() if flaw_created_dt else None

    json_flaw_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_date, Unset):
        json_flaw_created_dt_date = (
            flaw_created_dt_date.isoformat() if flaw_created_dt_date else None
        )

    json_flaw_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_date_gte, Unset):
        json_flaw_created_dt_date_gte = (
            flaw_created_dt_date_gte.isoformat() if flaw_created_dt_date_gte else None
        )

    json_flaw_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_date_lte, Unset):
        json_flaw_created_dt_date_lte = (
            flaw_created_dt_date_lte.isoformat() if flaw_created_dt_date_lte else None
        )

    json_flaw_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_gt, Unset):
        json_flaw_created_dt_gt = (
            flaw_created_dt_gt.isoformat() if flaw_created_dt_gt else None
        )

    json_flaw_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_gte, Unset):
        json_flaw_created_dt_gte = (
            flaw_created_dt_gte.isoformat() if flaw_created_dt_gte else None
        )

    json_flaw_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_lt, Unset):
        json_flaw_created_dt_lt = (
            flaw_created_dt_lt.isoformat() if flaw_created_dt_lt else None
        )

    json_flaw_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_created_dt_lte, Unset):
        json_flaw_created_dt_lte = (
            flaw_created_dt_lte.isoformat() if flaw_created_dt_lte else None
        )

    json_flaw_impact: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_impact, Unset):

        json_flaw_impact = (
            OsidbApiV1AffectsListFlawImpact(flaw_impact).value if flaw_impact else None
        )

    json_flaw_reported_dt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt, Unset):
        json_flaw_reported_dt = (
            flaw_reported_dt.isoformat() if flaw_reported_dt else None
        )

    json_flaw_reported_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_date, Unset):
        json_flaw_reported_dt_date = (
            flaw_reported_dt_date.isoformat() if flaw_reported_dt_date else None
        )

    json_flaw_reported_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_date_gte, Unset):
        json_flaw_reported_dt_date_gte = (
            flaw_reported_dt_date_gte.isoformat() if flaw_reported_dt_date_gte else None
        )

    json_flaw_reported_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_date_lte, Unset):
        json_flaw_reported_dt_date_lte = (
            flaw_reported_dt_date_lte.isoformat() if flaw_reported_dt_date_lte else None
        )

    json_flaw_reported_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_gt, Unset):
        json_flaw_reported_dt_gt = (
            flaw_reported_dt_gt.isoformat() if flaw_reported_dt_gt else None
        )

    json_flaw_reported_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_gte, Unset):
        json_flaw_reported_dt_gte = (
            flaw_reported_dt_gte.isoformat() if flaw_reported_dt_gte else None
        )

    json_flaw_reported_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_lt, Unset):
        json_flaw_reported_dt_lt = (
            flaw_reported_dt_lt.isoformat() if flaw_reported_dt_lt else None
        )

    json_flaw_reported_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_reported_dt_lte, Unset):
        json_flaw_reported_dt_lte = (
            flaw_reported_dt_lte.isoformat() if flaw_reported_dt_lte else None
        )

    json_flaw_source: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_source, Unset):

        json_flaw_source = (
            OsidbApiV1AffectsListFlawSource(flaw_source).value if flaw_source else None
        )

    json_flaw_type: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_type, Unset):

        json_flaw_type = (
            OsidbApiV1AffectsListFlawType(flaw_type).value if flaw_type else None
        )

    json_flaw_unembargo_dt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_unembargo_dt, Unset):
        json_flaw_unembargo_dt = (
            flaw_unembargo_dt.isoformat() if flaw_unembargo_dt else None
        )

    json_flaw_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt, Unset):
        json_flaw_updated_dt = flaw_updated_dt.isoformat() if flaw_updated_dt else None

    json_flaw_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_date, Unset):
        json_flaw_updated_dt_date = (
            flaw_updated_dt_date.isoformat() if flaw_updated_dt_date else None
        )

    json_flaw_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_date_gte, Unset):
        json_flaw_updated_dt_date_gte = (
            flaw_updated_dt_date_gte.isoformat() if flaw_updated_dt_date_gte else None
        )

    json_flaw_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_date_lte, Unset):
        json_flaw_updated_dt_date_lte = (
            flaw_updated_dt_date_lte.isoformat() if flaw_updated_dt_date_lte else None
        )

    json_flaw_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_gt, Unset):
        json_flaw_updated_dt_gt = (
            flaw_updated_dt_gt.isoformat() if flaw_updated_dt_gt else None
        )

    json_flaw_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_gte, Unset):
        json_flaw_updated_dt_gte = (
            flaw_updated_dt_gte.isoformat() if flaw_updated_dt_gte else None
        )

    json_flaw_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_lt, Unset):
        json_flaw_updated_dt_lt = (
            flaw_updated_dt_lt.isoformat() if flaw_updated_dt_lt else None
        )

    json_flaw_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(flaw_updated_dt_lte, Unset):
        json_flaw_updated_dt_lte = (
            flaw_updated_dt_lte.isoformat() if flaw_updated_dt_lte else None
        )

    json_impact: Union[Unset, None, str] = UNSET
    if not isinstance(impact, Unset):

        json_impact = OsidbApiV1AffectsListImpact(impact).value if impact else None

    json_include_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_fields, Unset):
        if include_fields is None:
            json_include_fields = None
        else:
            json_include_fields = include_fields

    json_include_meta_attr: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_meta_attr, Unset):
        if include_meta_attr is None:
            json_include_meta_attr = None
        else:
            json_include_meta_attr = include_meta_attr

    json_order: Union[Unset, None, List[str]] = UNSET
    if not isinstance(order, Unset):
        if order is None:
            json_order = None
        else:
            json_order = []
            for order_item_data in order:
                order_item: str = UNSET
                if not isinstance(order_item_data, Unset):

                    order_item = OsidbApiV1AffectsListOrderItem(order_item_data).value

                json_order.append(order_item)

    json_resolution: Union[Unset, None, str] = UNSET
    if not isinstance(resolution, Unset):

        json_resolution = (
            OsidbApiV1AffectsListResolution(resolution).value if resolution else None
        )

    json_trackers_created_dt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt, Unset):
        json_trackers_created_dt = (
            trackers_created_dt.isoformat() if trackers_created_dt else None
        )

    json_trackers_created_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_date, Unset):
        json_trackers_created_dt_date = (
            trackers_created_dt_date.isoformat() if trackers_created_dt_date else None
        )

    json_trackers_created_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_date_gte, Unset):
        json_trackers_created_dt_date_gte = (
            trackers_created_dt_date_gte.isoformat()
            if trackers_created_dt_date_gte
            else None
        )

    json_trackers_created_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_date_lte, Unset):
        json_trackers_created_dt_date_lte = (
            trackers_created_dt_date_lte.isoformat()
            if trackers_created_dt_date_lte
            else None
        )

    json_trackers_created_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_gt, Unset):
        json_trackers_created_dt_gt = (
            trackers_created_dt_gt.isoformat() if trackers_created_dt_gt else None
        )

    json_trackers_created_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_gte, Unset):
        json_trackers_created_dt_gte = (
            trackers_created_dt_gte.isoformat() if trackers_created_dt_gte else None
        )

    json_trackers_created_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_lt, Unset):
        json_trackers_created_dt_lt = (
            trackers_created_dt_lt.isoformat() if trackers_created_dt_lt else None
        )

    json_trackers_created_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_created_dt_lte, Unset):
        json_trackers_created_dt_lte = (
            trackers_created_dt_lte.isoformat() if trackers_created_dt_lte else None
        )

    json_trackers_type: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_type, Unset):

        json_trackers_type = (
            OsidbApiV1AffectsListTrackersType(trackers_type).value
            if trackers_type
            else None
        )

    json_trackers_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt, Unset):
        json_trackers_updated_dt = (
            trackers_updated_dt.isoformat() if trackers_updated_dt else None
        )

    json_trackers_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_date, Unset):
        json_trackers_updated_dt_date = (
            trackers_updated_dt_date.isoformat() if trackers_updated_dt_date else None
        )

    json_trackers_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_date_gte, Unset):
        json_trackers_updated_dt_date_gte = (
            trackers_updated_dt_date_gte.isoformat()
            if trackers_updated_dt_date_gte
            else None
        )

    json_trackers_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_date_lte, Unset):
        json_trackers_updated_dt_date_lte = (
            trackers_updated_dt_date_lte.isoformat()
            if trackers_updated_dt_date_lte
            else None
        )

    json_trackers_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_gt, Unset):
        json_trackers_updated_dt_gt = (
            trackers_updated_dt_gt.isoformat() if trackers_updated_dt_gt else None
        )

    json_trackers_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_gte, Unset):
        json_trackers_updated_dt_gte = (
            trackers_updated_dt_gte.isoformat() if trackers_updated_dt_gte else None
        )

    json_trackers_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_lt, Unset):
        json_trackers_updated_dt_lt = (
            trackers_updated_dt_lt.isoformat() if trackers_updated_dt_lt else None
        )

    json_trackers_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(trackers_updated_dt_lte, Unset):
        json_trackers_updated_dt_lte = (
            trackers_updated_dt_lte.isoformat() if trackers_updated_dt_lte else None
        )

    json_type: Union[Unset, None, str] = UNSET
    if not isinstance(type, Unset):

        json_type = OsidbApiV1AffectsListType(type).value if type else None

    json_updated_dt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt, Unset):
        json_updated_dt = updated_dt.isoformat() if updated_dt else None

    json_updated_dt_date: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date, Unset):
        json_updated_dt_date = updated_dt_date.isoformat() if updated_dt_date else None

    json_updated_dt_date_gte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date_gte, Unset):
        json_updated_dt_date_gte = (
            updated_dt_date_gte.isoformat() if updated_dt_date_gte else None
        )

    json_updated_dt_date_lte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_date_lte, Unset):
        json_updated_dt_date_lte = (
            updated_dt_date_lte.isoformat() if updated_dt_date_lte else None
        )

    json_updated_dt_gt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_gt, Unset):
        json_updated_dt_gt = updated_dt_gt.isoformat() if updated_dt_gt else None

    json_updated_dt_gte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_gte, Unset):
        json_updated_dt_gte = updated_dt_gte.isoformat() if updated_dt_gte else None

    json_updated_dt_lt: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_lt, Unset):
        json_updated_dt_lt = updated_dt_lt.isoformat() if updated_dt_lt else None

    json_updated_dt_lte: Union[Unset, None, str] = UNSET
    if not isinstance(updated_dt_lte, Unset):
        json_updated_dt_lte = updated_dt_lte.isoformat() if updated_dt_lte else None

    params: Dict[str, Any] = {
        "affectedness": json_affectedness,
        "created_dt": json_created_dt,
        "created_dt__date": json_created_dt_date,
        "created_dt__date__gte": json_created_dt_date_gte,
        "created_dt__date__lte": json_created_dt_date_lte,
        "created_dt__gt": json_created_dt_gt,
        "created_dt__gte": json_created_dt_gte,
        "created_dt__lt": json_created_dt_lt,
        "created_dt__lte": json_created_dt_lte,
        "cvss2": cvss2,
        "cvss2_score": cvss2_score,
        "cvss2_score__gt": cvss2_score_gt,
        "cvss2_score__gte": cvss2_score_gte,
        "cvss2_score__lt": cvss2_score_lt,
        "cvss2_score__lte": cvss2_score_lte,
        "cvss3": cvss3,
        "cvss3_score": cvss3_score,
        "cvss3_score__gt": cvss3_score_gt,
        "cvss3_score__gte": cvss3_score_gte,
        "cvss3_score__lt": cvss3_score_lt,
        "cvss3_score__lte": cvss3_score_lte,
        "embargoed": embargoed,
        "exclude_fields": json_exclude_fields,
        "flaw__component": flaw_component,
        "flaw__created_dt": json_flaw_created_dt,
        "flaw__created_dt__date": json_flaw_created_dt_date,
        "flaw__created_dt__date__gte": json_flaw_created_dt_date_gte,
        "flaw__created_dt__date__lte": json_flaw_created_dt_date_lte,
        "flaw__created_dt__gt": json_flaw_created_dt_gt,
        "flaw__created_dt__gte": json_flaw_created_dt_gte,
        "flaw__created_dt__lt": json_flaw_created_dt_lt,
        "flaw__created_dt__lte": json_flaw_created_dt_lte,
        "flaw__cve_id": flaw_cve_id,
        "flaw__cvss2": flaw_cvss2,
        "flaw__cvss2_score": flaw_cvss2_score,
        "flaw__cvss2_score__gt": flaw_cvss2_score_gt,
        "flaw__cvss2_score__gte": flaw_cvss2_score_gte,
        "flaw__cvss2_score__lt": flaw_cvss2_score_lt,
        "flaw__cvss2_score__lte": flaw_cvss2_score_lte,
        "flaw__cvss3": flaw_cvss3,
        "flaw__cvss3_score": flaw_cvss3_score,
        "flaw__cvss3_score__gt": flaw_cvss3_score_gt,
        "flaw__cvss3_score__gte": flaw_cvss3_score_gte,
        "flaw__cvss3_score__lt": flaw_cvss3_score_lt,
        "flaw__cvss3_score__lte": flaw_cvss3_score_lte,
        "flaw__cwe_id": flaw_cwe_id,
        "flaw__embargoed": flaw_embargoed,
        "flaw__impact": json_flaw_impact,
        "flaw__is_major_incident": flaw_is_major_incident,
        "flaw__nvd_cvss2": flaw_nvd_cvss2,
        "flaw__nvd_cvss3": flaw_nvd_cvss3,
        "flaw__reported_dt": json_flaw_reported_dt,
        "flaw__reported_dt__date": json_flaw_reported_dt_date,
        "flaw__reported_dt__date__gte": json_flaw_reported_dt_date_gte,
        "flaw__reported_dt__date__lte": json_flaw_reported_dt_date_lte,
        "flaw__reported_dt__gt": json_flaw_reported_dt_gt,
        "flaw__reported_dt__gte": json_flaw_reported_dt_gte,
        "flaw__reported_dt__lt": json_flaw_reported_dt_lt,
        "flaw__reported_dt__lte": json_flaw_reported_dt_lte,
        "flaw__source": json_flaw_source,
        "flaw__type": json_flaw_type,
        "flaw__unembargo_dt": json_flaw_unembargo_dt,
        "flaw__updated_dt": json_flaw_updated_dt,
        "flaw__updated_dt__date": json_flaw_updated_dt_date,
        "flaw__updated_dt__date__gte": json_flaw_updated_dt_date_gte,
        "flaw__updated_dt__date__lte": json_flaw_updated_dt_date_lte,
        "flaw__updated_dt__gt": json_flaw_updated_dt_gt,
        "flaw__updated_dt__gte": json_flaw_updated_dt_gte,
        "flaw__updated_dt__lt": json_flaw_updated_dt_lt,
        "flaw__updated_dt__lte": json_flaw_updated_dt_lte,
        "flaw__uuid": flaw_uuid,
        "impact": json_impact,
        "include_fields": json_include_fields,
        "include_meta_attr": json_include_meta_attr,
        "limit": limit,
        "offset": offset,
        "order": json_order,
        "ps_component": ps_component,
        "ps_module": ps_module,
        "resolution": json_resolution,
        "trackers__created_dt": json_trackers_created_dt,
        "trackers__created_dt__date": json_trackers_created_dt_date,
        "trackers__created_dt__date__gte": json_trackers_created_dt_date_gte,
        "trackers__created_dt__date__lte": json_trackers_created_dt_date_lte,
        "trackers__created_dt__gt": json_trackers_created_dt_gt,
        "trackers__created_dt__gte": json_trackers_created_dt_gte,
        "trackers__created_dt__lt": json_trackers_created_dt_lt,
        "trackers__created_dt__lte": json_trackers_created_dt_lte,
        "trackers__embargoed": trackers_embargoed,
        "trackers__external_system_id": trackers_external_system_id,
        "trackers__ps_update_stream": trackers_ps_update_stream,
        "trackers__resolution": trackers_resolution,
        "trackers__status": trackers_status,
        "trackers__type": json_trackers_type,
        "trackers__updated_dt": json_trackers_updated_dt,
        "trackers__updated_dt__date": json_trackers_updated_dt_date,
        "trackers__updated_dt__date__gte": json_trackers_updated_dt_date_gte,
        "trackers__updated_dt__date__lte": json_trackers_updated_dt_date_lte,
        "trackers__updated_dt__gt": json_trackers_updated_dt_gt,
        "trackers__updated_dt__gte": json_trackers_updated_dt_gte,
        "trackers__updated_dt__lt": json_trackers_updated_dt_lt,
        "trackers__updated_dt__lte": json_trackers_updated_dt_lte,
        "trackers__uuid": trackers_uuid,
        "type": json_type,
        "updated_dt": json_updated_dt,
        "updated_dt__date": json_updated_dt_date,
        "updated_dt__date__gte": json_updated_dt_date_gte,
        "updated_dt__date__lte": json_updated_dt_date_lte,
        "updated_dt__gt": json_updated_dt_gt,
        "updated_dt__gte": json_updated_dt_gte,
        "updated_dt__lt": json_updated_dt_lt,
        "updated_dt__lte": json_updated_dt_lte,
        "uuid": uuid,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "params": params,
    }


def _parse_response(
    *, response: requests.Response
) -> Optional[OsidbApiV1AffectsListResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1AffectsListResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1AffectsListResponse200.from_dict(_response_200)

        return response_200
    return None


def _build_response(
    *, response: requests.Response
) -> Response[OsidbApiV1AffectsListResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss2_score_gt: Union[Unset, None, float] = UNSET,
    cvss2_score_gte: Union[Unset, None, float] = UNSET,
    cvss2_score_lt: Union[Unset, None, float] = UNSET,
    cvss2_score_lte: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cvss3_score_gt: Union[Unset, None, float] = UNSET,
    cvss3_score_gte: Union[Unset, None, float] = UNSET,
    cvss3_score_lt: Union[Unset, None, float] = UNSET,
    cvss3_score_lte: Union[Unset, None, float] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_component: Union[Unset, None, str] = UNSET,
    flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_cve_id: Union[Unset, None, str] = UNSET,
    flaw_cvss2: Union[Unset, None, str] = UNSET,
    flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cvss3: Union[Unset, None, str] = UNSET,
    flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cwe_id: Union[Unset, None, str] = UNSET,
    flaw_embargoed: Union[Unset, None, bool] = UNSET,
    flaw_impact: Union[Unset, None, OsidbApiV1AffectsListFlawImpact] = UNSET,
    flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_source: Union[Unset, None, OsidbApiV1AffectsListFlawSource] = UNSET,
    flaw_type: Union[Unset, None, OsidbApiV1AffectsListFlawType] = UNSET,
    flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_uuid: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1AffectsListOrderItem]] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    trackers_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_embargoed: Union[Unset, None, bool] = UNSET,
    trackers_external_system_id: Union[Unset, None, str] = UNSET,
    trackers_ps_update_stream: Union[Unset, None, str] = UNSET,
    trackers_resolution: Union[Unset, None, str] = UNSET,
    trackers_status: Union[Unset, None, str] = UNSET,
    trackers_type: Union[Unset, None, OsidbApiV1AffectsListTrackersType] = UNSET,
    trackers_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_uuid: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Response[OsidbApiV1AffectsListResponse200]:
    kwargs = _get_kwargs(
        client=client,
        affectedness=affectedness,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cvss2=cvss2,
        cvss2_score=cvss2_score,
        cvss2_score_gt=cvss2_score_gt,
        cvss2_score_gte=cvss2_score_gte,
        cvss2_score_lt=cvss2_score_lt,
        cvss2_score_lte=cvss2_score_lte,
        cvss3=cvss3,
        cvss3_score=cvss3_score,
        cvss3_score_gt=cvss3_score_gt,
        cvss3_score_gte=cvss3_score_gte,
        cvss3_score_lt=cvss3_score_lt,
        cvss3_score_lte=cvss3_score_lte,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        flaw_component=flaw_component,
        flaw_created_dt=flaw_created_dt,
        flaw_created_dt_date=flaw_created_dt_date,
        flaw_created_dt_date_gte=flaw_created_dt_date_gte,
        flaw_created_dt_date_lte=flaw_created_dt_date_lte,
        flaw_created_dt_gt=flaw_created_dt_gt,
        flaw_created_dt_gte=flaw_created_dt_gte,
        flaw_created_dt_lt=flaw_created_dt_lt,
        flaw_created_dt_lte=flaw_created_dt_lte,
        flaw_cve_id=flaw_cve_id,
        flaw_cvss2=flaw_cvss2,
        flaw_cvss2_score=flaw_cvss2_score,
        flaw_cvss2_score_gt=flaw_cvss2_score_gt,
        flaw_cvss2_score_gte=flaw_cvss2_score_gte,
        flaw_cvss2_score_lt=flaw_cvss2_score_lt,
        flaw_cvss2_score_lte=flaw_cvss2_score_lte,
        flaw_cvss3=flaw_cvss3,
        flaw_cvss3_score=flaw_cvss3_score,
        flaw_cvss3_score_gt=flaw_cvss3_score_gt,
        flaw_cvss3_score_gte=flaw_cvss3_score_gte,
        flaw_cvss3_score_lt=flaw_cvss3_score_lt,
        flaw_cvss3_score_lte=flaw_cvss3_score_lte,
        flaw_cwe_id=flaw_cwe_id,
        flaw_embargoed=flaw_embargoed,
        flaw_impact=flaw_impact,
        flaw_is_major_incident=flaw_is_major_incident,
        flaw_nvd_cvss2=flaw_nvd_cvss2,
        flaw_nvd_cvss3=flaw_nvd_cvss3,
        flaw_reported_dt=flaw_reported_dt,
        flaw_reported_dt_date=flaw_reported_dt_date,
        flaw_reported_dt_date_gte=flaw_reported_dt_date_gte,
        flaw_reported_dt_date_lte=flaw_reported_dt_date_lte,
        flaw_reported_dt_gt=flaw_reported_dt_gt,
        flaw_reported_dt_gte=flaw_reported_dt_gte,
        flaw_reported_dt_lt=flaw_reported_dt_lt,
        flaw_reported_dt_lte=flaw_reported_dt_lte,
        flaw_source=flaw_source,
        flaw_type=flaw_type,
        flaw_unembargo_dt=flaw_unembargo_dt,
        flaw_updated_dt=flaw_updated_dt,
        flaw_updated_dt_date=flaw_updated_dt_date,
        flaw_updated_dt_date_gte=flaw_updated_dt_date_gte,
        flaw_updated_dt_date_lte=flaw_updated_dt_date_lte,
        flaw_updated_dt_gt=flaw_updated_dt_gt,
        flaw_updated_dt_gte=flaw_updated_dt_gte,
        flaw_updated_dt_lt=flaw_updated_dt_lt,
        flaw_updated_dt_lte=flaw_updated_dt_lte,
        flaw_uuid=flaw_uuid,
        impact=impact,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_component=ps_component,
        ps_module=ps_module,
        resolution=resolution,
        trackers_created_dt=trackers_created_dt,
        trackers_created_dt_date=trackers_created_dt_date,
        trackers_created_dt_date_gte=trackers_created_dt_date_gte,
        trackers_created_dt_date_lte=trackers_created_dt_date_lte,
        trackers_created_dt_gt=trackers_created_dt_gt,
        trackers_created_dt_gte=trackers_created_dt_gte,
        trackers_created_dt_lt=trackers_created_dt_lt,
        trackers_created_dt_lte=trackers_created_dt_lte,
        trackers_embargoed=trackers_embargoed,
        trackers_external_system_id=trackers_external_system_id,
        trackers_ps_update_stream=trackers_ps_update_stream,
        trackers_resolution=trackers_resolution,
        trackers_status=trackers_status,
        trackers_type=trackers_type,
        trackers_updated_dt=trackers_updated_dt,
        trackers_updated_dt_date=trackers_updated_dt_date,
        trackers_updated_dt_date_gte=trackers_updated_dt_date_gte,
        trackers_updated_dt_date_lte=trackers_updated_dt_date_lte,
        trackers_updated_dt_gt=trackers_updated_dt_gt,
        trackers_updated_dt_gte=trackers_updated_dt_gte,
        trackers_updated_dt_lt=trackers_updated_dt_lt,
        trackers_updated_dt_lte=trackers_updated_dt_lte,
        trackers_uuid=trackers_uuid,
        type=type,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    affectedness: Union[Unset, None, OsidbApiV1AffectsListAffectedness] = UNSET,
    created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    cvss2: Union[Unset, None, str] = UNSET,
    cvss2_score: Union[Unset, None, float] = UNSET,
    cvss2_score_gt: Union[Unset, None, float] = UNSET,
    cvss2_score_gte: Union[Unset, None, float] = UNSET,
    cvss2_score_lt: Union[Unset, None, float] = UNSET,
    cvss2_score_lte: Union[Unset, None, float] = UNSET,
    cvss3: Union[Unset, None, str] = UNSET,
    cvss3_score: Union[Unset, None, float] = UNSET,
    cvss3_score_gt: Union[Unset, None, float] = UNSET,
    cvss3_score_gte: Union[Unset, None, float] = UNSET,
    cvss3_score_lt: Union[Unset, None, float] = UNSET,
    cvss3_score_lte: Union[Unset, None, float] = UNSET,
    embargoed: Union[Unset, None, bool] = UNSET,
    exclude_fields: Union[Unset, None, List[str]] = UNSET,
    flaw_component: Union[Unset, None, str] = UNSET,
    flaw_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_cve_id: Union[Unset, None, str] = UNSET,
    flaw_cvss2: Union[Unset, None, str] = UNSET,
    flaw_cvss2_score: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss2_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cvss3: Union[Unset, None, str] = UNSET,
    flaw_cvss3_score: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_gte: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lt: Union[Unset, None, float] = UNSET,
    flaw_cvss3_score_lte: Union[Unset, None, float] = UNSET,
    flaw_cwe_id: Union[Unset, None, str] = UNSET,
    flaw_embargoed: Union[Unset, None, bool] = UNSET,
    flaw_impact: Union[Unset, None, OsidbApiV1AffectsListFlawImpact] = UNSET,
    flaw_is_major_incident: Union[Unset, None, bool] = UNSET,
    flaw_nvd_cvss2: Union[Unset, None, str] = UNSET,
    flaw_nvd_cvss3: Union[Unset, None, str] = UNSET,
    flaw_reported_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_reported_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_reported_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_source: Union[Unset, None, OsidbApiV1AffectsListFlawSource] = UNSET,
    flaw_type: Union[Unset, None, OsidbApiV1AffectsListFlawType] = UNSET,
    flaw_unembargo_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    flaw_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    flaw_uuid: Union[Unset, None, str] = UNSET,
    impact: Union[Unset, None, OsidbApiV1AffectsListImpact] = UNSET,
    include_fields: Union[Unset, None, List[str]] = UNSET,
    include_meta_attr: Union[Unset, None, List[str]] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    offset: Union[Unset, None, int] = UNSET,
    order: Union[Unset, None, List[OsidbApiV1AffectsListOrderItem]] = UNSET,
    ps_component: Union[Unset, None, str] = UNSET,
    ps_module: Union[Unset, None, str] = UNSET,
    resolution: Union[Unset, None, OsidbApiV1AffectsListResolution] = UNSET,
    trackers_created_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_created_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_created_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_embargoed: Union[Unset, None, bool] = UNSET,
    trackers_external_system_id: Union[Unset, None, str] = UNSET,
    trackers_ps_update_stream: Union[Unset, None, str] = UNSET,
    trackers_resolution: Union[Unset, None, str] = UNSET,
    trackers_status: Union[Unset, None, str] = UNSET,
    trackers_type: Union[Unset, None, OsidbApiV1AffectsListTrackersType] = UNSET,
    trackers_updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    trackers_updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    trackers_uuid: Union[Unset, None, str] = UNSET,
    type: Union[Unset, None, OsidbApiV1AffectsListType] = UNSET,
    updated_dt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, None, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, None, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, None, datetime.datetime] = UNSET,
    uuid: Union[Unset, None, str] = UNSET,
) -> Optional[OsidbApiV1AffectsListResponse200]:
    """ """

    return sync_detailed(
        client=client,
        affectedness=affectedness,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cvss2=cvss2,
        cvss2_score=cvss2_score,
        cvss2_score_gt=cvss2_score_gt,
        cvss2_score_gte=cvss2_score_gte,
        cvss2_score_lt=cvss2_score_lt,
        cvss2_score_lte=cvss2_score_lte,
        cvss3=cvss3,
        cvss3_score=cvss3_score,
        cvss3_score_gt=cvss3_score_gt,
        cvss3_score_gte=cvss3_score_gte,
        cvss3_score_lt=cvss3_score_lt,
        cvss3_score_lte=cvss3_score_lte,
        embargoed=embargoed,
        exclude_fields=exclude_fields,
        flaw_component=flaw_component,
        flaw_created_dt=flaw_created_dt,
        flaw_created_dt_date=flaw_created_dt_date,
        flaw_created_dt_date_gte=flaw_created_dt_date_gte,
        flaw_created_dt_date_lte=flaw_created_dt_date_lte,
        flaw_created_dt_gt=flaw_created_dt_gt,
        flaw_created_dt_gte=flaw_created_dt_gte,
        flaw_created_dt_lt=flaw_created_dt_lt,
        flaw_created_dt_lte=flaw_created_dt_lte,
        flaw_cve_id=flaw_cve_id,
        flaw_cvss2=flaw_cvss2,
        flaw_cvss2_score=flaw_cvss2_score,
        flaw_cvss2_score_gt=flaw_cvss2_score_gt,
        flaw_cvss2_score_gte=flaw_cvss2_score_gte,
        flaw_cvss2_score_lt=flaw_cvss2_score_lt,
        flaw_cvss2_score_lte=flaw_cvss2_score_lte,
        flaw_cvss3=flaw_cvss3,
        flaw_cvss3_score=flaw_cvss3_score,
        flaw_cvss3_score_gt=flaw_cvss3_score_gt,
        flaw_cvss3_score_gte=flaw_cvss3_score_gte,
        flaw_cvss3_score_lt=flaw_cvss3_score_lt,
        flaw_cvss3_score_lte=flaw_cvss3_score_lte,
        flaw_cwe_id=flaw_cwe_id,
        flaw_embargoed=flaw_embargoed,
        flaw_impact=flaw_impact,
        flaw_is_major_incident=flaw_is_major_incident,
        flaw_nvd_cvss2=flaw_nvd_cvss2,
        flaw_nvd_cvss3=flaw_nvd_cvss3,
        flaw_reported_dt=flaw_reported_dt,
        flaw_reported_dt_date=flaw_reported_dt_date,
        flaw_reported_dt_date_gte=flaw_reported_dt_date_gte,
        flaw_reported_dt_date_lte=flaw_reported_dt_date_lte,
        flaw_reported_dt_gt=flaw_reported_dt_gt,
        flaw_reported_dt_gte=flaw_reported_dt_gte,
        flaw_reported_dt_lt=flaw_reported_dt_lt,
        flaw_reported_dt_lte=flaw_reported_dt_lte,
        flaw_source=flaw_source,
        flaw_type=flaw_type,
        flaw_unembargo_dt=flaw_unembargo_dt,
        flaw_updated_dt=flaw_updated_dt,
        flaw_updated_dt_date=flaw_updated_dt_date,
        flaw_updated_dt_date_gte=flaw_updated_dt_date_gte,
        flaw_updated_dt_date_lte=flaw_updated_dt_date_lte,
        flaw_updated_dt_gt=flaw_updated_dt_gt,
        flaw_updated_dt_gte=flaw_updated_dt_gte,
        flaw_updated_dt_lt=flaw_updated_dt_lt,
        flaw_updated_dt_lte=flaw_updated_dt_lte,
        flaw_uuid=flaw_uuid,
        impact=impact,
        include_fields=include_fields,
        include_meta_attr=include_meta_attr,
        limit=limit,
        offset=offset,
        order=order,
        ps_component=ps_component,
        ps_module=ps_module,
        resolution=resolution,
        trackers_created_dt=trackers_created_dt,
        trackers_created_dt_date=trackers_created_dt_date,
        trackers_created_dt_date_gte=trackers_created_dt_date_gte,
        trackers_created_dt_date_lte=trackers_created_dt_date_lte,
        trackers_created_dt_gt=trackers_created_dt_gt,
        trackers_created_dt_gte=trackers_created_dt_gte,
        trackers_created_dt_lt=trackers_created_dt_lt,
        trackers_created_dt_lte=trackers_created_dt_lte,
        trackers_embargoed=trackers_embargoed,
        trackers_external_system_id=trackers_external_system_id,
        trackers_ps_update_stream=trackers_ps_update_stream,
        trackers_resolution=trackers_resolution,
        trackers_status=trackers_status,
        trackers_type=trackers_type,
        trackers_updated_dt=trackers_updated_dt,
        trackers_updated_dt_date=trackers_updated_dt_date,
        trackers_updated_dt_date_gte=trackers_updated_dt_date_gte,
        trackers_updated_dt_date_lte=trackers_updated_dt_date_lte,
        trackers_updated_dt_gt=trackers_updated_dt_gt,
        trackers_updated_dt_gte=trackers_updated_dt_gte,
        trackers_updated_dt_lt=trackers_updated_dt_lt,
        trackers_updated_dt_lte=trackers_updated_dt_lte,
        trackers_uuid=trackers_uuid,
        type=type,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.jira_issue_type import JiraIssueType
from ..models.jira_user import JiraUser
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="JiraIssueFields")


@attr.s(auto_attribs=True)
class JiraIssueFields(OSIDBModel):
    """ """

    issuetype: JiraIssueType
    summary: str
    description: str
    assignee: JiraUser
    reporter: JiraUser
    creator: JiraUser
    customfield_12311140: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        issuetype: Dict[str, Any] = UNSET
        if not isinstance(self.issuetype, Unset):
            issuetype = self.issuetype.to_dict()

        summary = self.summary
        description = self.description
        assignee: Dict[str, Any] = UNSET
        if not isinstance(self.assignee, Unset):
            assignee = self.assignee.to_dict()

        reporter: Dict[str, Any] = UNSET
        if not isinstance(self.reporter, Unset):
            reporter = self.reporter.to_dict()

        creator: Dict[str, Any] = UNSET
        if not isinstance(self.creator, Unset):
            creator = self.creator.to_dict()

        customfield_12311140 = self.customfield_12311140

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if issuetype is not UNSET:
            field_dict["issuetype"] = issuetype
        if summary is not UNSET:
            field_dict["summary"] = summary
        if description is not UNSET:
            field_dict["description"] = description
        if assignee is not UNSET:
            field_dict["assignee"] = assignee
        if reporter is not UNSET:
            field_dict["reporter"] = reporter
        if creator is not UNSET:
            field_dict["creator"] = creator
        if customfield_12311140 is not UNSET:
            field_dict["customfield_12311140"] = customfield_12311140

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _issuetype = d.pop("issuetype", UNSET)
        issuetype: JiraIssueType
        if isinstance(_issuetype, Unset):
            issuetype = UNSET
        else:
            issuetype = JiraIssueType.from_dict(_issuetype)

        summary = d.pop("summary", UNSET)

        description = d.pop("description", UNSET)

        _assignee = d.pop("assignee", UNSET)
        assignee: JiraUser
        if isinstance(_assignee, Unset):
            assignee = UNSET
        else:
            assignee = JiraUser.from_dict(_assignee)

        _reporter = d.pop("reporter", UNSET)
        reporter: JiraUser
        if isinstance(_reporter, Unset):
            reporter = UNSET
        else:
            reporter = JiraUser.from_dict(_reporter)

        _creator = d.pop("creator", UNSET)
        creator: JiraUser
        if isinstance(_creator, Unset):
            creator = UNSET
        else:
            creator = JiraUser.from_dict(_creator)

        customfield_12311140 = d.pop("customfield_12311140", UNSET)

        jira_issue_fields = cls(
            issuetype=issuetype,
            summary=summary,
            description=description,
            assignee=assignee,
            reporter=reporter,
            creator=creator,
            customfield_12311140=customfield_12311140,
        )

        jira_issue_fields.additional_properties = d
        return jira_issue_fields

    @staticmethod
    def get_fields():
        return {
            "issuetype": JiraIssueType,
            "summary": str,
            "description": str,
            "assignee": JiraUser,
            "reporter": JiraUser,
            "creator": JiraUser,
            "customfield_12311140": str,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.flaw_comment_type import FlawCommentType
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="FlawComment")


@attr.s(auto_attribs=True)
class FlawComment(OSIDBModel):
    """FlawComment serializer for use by flaw_comments endpoint"""

    flaw: str
    text: str
    uuid: str
    external_system_id: str
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    embargoed: bool
    type: Union[Unset, FlawCommentType] = UNSET
    order: Union[Unset, None, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        flaw = self.flaw
        text = self.text
        uuid = self.uuid
        external_system_id = self.external_system_id
        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        embargoed = self.embargoed
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):

            type = FlawCommentType(self.type).value

        order = self.order

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if flaw is not UNSET:
            field_dict["flaw"] = flaw
        if text is not UNSET:
            field_dict["text"] = text
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if external_system_id is not UNSET:
            field_dict["external_system_id"] = external_system_id
        if created_dt is not UNSET:
            field_dict["created_dt"] = created_dt
        if updated_dt is not UNSET:
            field_dict["updated_dt"] = updated_dt
        if embargoed is not UNSET:
            field_dict["embargoed"] = embargoed
        if type is not UNSET:
            field_dict["type"] = type
        if order is not UNSET:
            field_dict["order"] = order

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        flaw = d.pop("flaw", UNSET)

        text = d.pop("text", UNSET)

        uuid = d.pop("uuid", UNSET)

        external_system_id = d.pop("external_system_id", UNSET)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        embargoed = d.pop("embargoed", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[Unset, FlawCommentType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = FlawCommentType(_type)

        order = d.pop("order", UNSET)

        flaw_comment = cls(
            flaw=flaw,
            text=text,
            uuid=uuid,
            external_system_id=external_system_id,
            created_dt=created_dt,
            updated_dt=updated_dt,
            embargoed=embargoed,
            type=type,
            order=order,
        )

        flaw_comment.additional_properties = d
        return flaw_comment

    @staticmethod
    def get_fields():
        return {
            "flaw": str,
            "text": str,
            "uuid": str,
            "external_system_id": str,
            "created_dt": datetime.datetime,
            "updated_dt": datetime.datetime,
            "embargoed": bool,
            "type": FlawCommentType,
            "order": int,
        }

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
